:tocdepth: 2

.. _authors:

Authors
=======

py7zr is written and maintained by Hiroshi Miura <miurahr@linux.com>

Contributors, listed alphabetically, are:

* @andrebrait -- Fix exception for empty 7z file (#118)
* Joachim Bauch -- pylzma orginator
* Kazuya Fujioka -- Fix zero file problem
* Kyle Altendorf -- Fix multithreading problem (#82)
* @royopa -- Fix typo (#108)
* @Zoynels -- Mmeory IO API(#111, #119)
